@@ -8,7 +8,7 @@
  *
  * Order of sections for common.inc.php:
  *
- * the authentication libraries must be loaded before db connections
+ * the authentication libraries must be before the connection to db
  *
  * ... so the required order is:
  *
@@ -28,9 +28,25 @@
  * - db connection
  * - authentication work
  *
- * @version $Id: common.inc.php 11638 2008-10-08 12:14:19Z lem9 $
+ * @version $Id$
+ * @package phpMyAdmin
  */
 
+/**
+ * Minimum PHP version; can't call PMA_fatalError() which uses a
+ * PHP 5 function, so cannot easily localize this message.
+ */
+if (version_compare(PHP_VERSION, '5.2.0', 'lt')) {
+    die('PHP 5.2+ is required');
+}
+
+/**
+  * Backward compatibility for PHP 5.2
+  */
+if (!defined('E_DEPRECATED')) {
+    define('E_DEPRECATED', 8192);
+}
+
 /**
  * the error handler
  */
@@ -40,6 +56,7 @@ require_once './libraries/Error_Handler.class.php';
  * initialize the error handler
  */
 $GLOBALS['error_handler'] = new PMA_Error_Handler();
+$cfg['Error_Handler']['display'] = TRUE;
 
 // at this point PMA_PHP_INT_VERSION is not yet defined
 if (version_compare(phpversion(), '6', 'lt')) {
@@ -71,13 +88,7 @@ require_once './libraries/sanitizing.lib.php';
 
 /**
  * the PMA_Theme class
- * (this one is the first to produce a fatal error under PHP < 5)
- * and let's put here the same minimum requirement as in our doc.
  */
-if (version_compare(PHP_VERSION, '5.2.0') < 0 ) {
-    PMA_fatalError('strUpgrade', array('PHP', '5.2'));
-}
-
 require_once './libraries/Theme.class.php';
 
 /**
@@ -90,6 +101,16 @@ require_once './libraries/Theme_Manager.class.php';
  */
 require_once './libraries/Config.class.php';
 
+/**
+ * the relation lib, tracker needs it
+ */
+require_once './libraries/relation.lib.php';
+
+/**
+ * the PMA_Tracker class
+ */
+require_once './libraries/Tracker.class.php';
+
 /**
  * the PMA_Table class
  */
@@ -195,7 +216,7 @@ unset($key, $value, $variables_whitelist);
  * ... main form elments ...
  * <input type="submit" name="main_action" value="submit form" />
  * </form>
- * </code
+ * </code>
  *
  * so we now check if a subform is submitted
  */
@@ -229,9 +250,7 @@ if (isset($_POST['usesubform'])) {
 // end check if a subform is submitted
 
 // remove quotes added by php
-// (get_magic_quotes_gpc() is deprecated in PHP 5.3, but compare with 5.2.99
-// to be able to test with 5.3.0-dev)
-if (function_exists('get_magic_quotes_gpc') && -1 == version_compare(PHP_VERSION, '5.2.99') && get_magic_quotes_gpc()) {
+if (function_exists('get_magic_quotes_gpc') && get_magic_quotes_gpc()) {
     PMA_arrayWalkRecursive($_GET, 'stripslashes', true);
     PMA_arrayWalkRecursive($_POST, 'stripslashes', true);
     PMA_arrayWalkRecursive($_COOKIE, 'stripslashes', true);
@@ -306,7 +325,6 @@ $goto_whitelist = array(
     'db_printview.php',
     'db_search.php',
     //'Documentation.html',
-    //'error.php',
     'export.php',
     'import.php',
     //'index.php',
@@ -409,6 +427,10 @@ if (! PMA_isValid($_REQUEST['token']) || $_SESSION[' PMA_token '] != $_REQUEST['
         'pma_lang', 'pma_charset', 'pma_collation_connection',
         /* Possible login form */
         'pma_servername', 'pma_username', 'pma_password',
+        /* rajk - for playing blobstreamable media */
+        'media_type', 'custom_type', 'bs_reference',
+        /* rajk - for changing BLOB repository file MIME type */
+        'bs_db', 'bs_table', 'bs_ref', 'bs_new_mime_type'
     );
     /**
      * Require cleanup functions
@@ -535,6 +557,8 @@ if ($_SESSION['PMA_Config']->get('ForceSSL')
         preg_replace('/^http/', 'https',
             $_SESSION['PMA_Config']->get('PmaAbsoluteUri'))
         . PMA_generate_common_url($_GET, 'text'));
+    // delete the current session, otherwise we get problems (see bug #2397877)
+    PMA_removeCookie($GLOBALS['session_name']);
     exit;
 }
 
@@ -638,11 +662,11 @@ unset($default_server);
 /* setup themes                                          LABEL_theme_setup    */
 
 if (isset($_REQUEST['custom_color_reset'])) {
-    unset($_SESSION['userconf']['custom_color']);
-    unset($_SESSION['userconf']['custom_color_rgb']);
+    unset($_SESSION['tmp_user_values']['custom_color']);
+    unset($_SESSION['tmp_user_values']['custom_color_rgb']);
 } elseif (isset($_REQUEST['custom_color'])) {
-    $_SESSION['userconf']['custom_color'] = $_REQUEST['custom_color'];
-    $_SESSION['userconf']['custom_color_rgb'] = $_REQUEST['custom_color_rgb'];
+    $_SESSION['tmp_user_values']['custom_color'] = $_REQUEST['custom_color'];
+    $_SESSION['tmp_user_values']['custom_color_rgb'] = $_REQUEST['custom_color_rgb'];
 }
 /**
  * @global PMA_Theme_Manager $_SESSION['PMA_Theme_Manager']
@@ -703,7 +727,7 @@ $GLOBALS['pmaThemeImage']   = $_SESSION['PMA_Theme']->getImgPath();
 if (@file_exists($_SESSION['PMA_Theme']->getLayoutFile())) {
     include $_SESSION['PMA_Theme']->getLayoutFile();
     /**
-     * @todo remove if all themes are updated to use Navi instead of Left as frame name
+     * @todo remove if all themes are update use Navi instead of Left as frame name
      */
     if (! isset($GLOBALS['cfg']['NaviWidth'])
      && isset($GLOBALS['cfg']['LeftWidth'])) {
@@ -793,6 +817,8 @@ if (! defined('PMA_MINIMUM_COMMON')) {
          */
         require_once './libraries/database_interface.lib.php';
 
+        require_once './libraries/logging.lib.php';
+
         // Gets the authentication library that fits the $cfg['Server'] settings
         // and run authentication
 
@@ -853,7 +879,8 @@ if (! defined('PMA_MINIMUM_COMMON')) {
 
             // Ejects the user if banished
             if ($allowDeny_forbidden) {
-               PMA_auth_fails();
+                PMA_log_user($cfg['Server']['user'], 'allow-denied');
+                PMA_auth_fails();
             }
             unset($allowDeny_forbidden); //Clean up after you!
         } // end if
@@ -861,10 +888,19 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         // is root allowed?
         if (!$cfg['Server']['AllowRoot'] && $cfg['Server']['user'] == 'root') {
             $allowDeny_forbidden = true;
+            PMA_log_user($cfg['Server']['user'], 'root-denied');
             PMA_auth_fails();
             unset($allowDeny_forbidden); //Clean up after you!
         }
 
+        // is a login without password allowed?
+        if (!$cfg['Server']['AllowNoPassword'] && $cfg['Server']['password'] == '') {
+            $login_without_password_is_forbidden = true;
+            PMA_log_user($cfg['Server']['user'], 'empty-denied');
+            PMA_auth_fails();
+            unset($login_without_password_is_forbidden); //Clean up after you!
+        }
+
         // Try to connect MySQL with the control user profile (will be used to
         // get the privileges list for the current user but the true user link
         // must be open after this one so it would be default one for all the
@@ -883,6 +919,9 @@ if (! defined('PMA_MINIMUM_COMMON')) {
             $controllink = $userlink;
         }
 
+        /* Log success */
+        PMA_log_user($cfg['Server']['user']);
+
         /**
          * with phpMyAdmin 3 we support MySQL >=5
          * but only production releases:
@@ -913,10 +952,10 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         /**
          * some resetting has to be done when switching servers
          */
-        if (isset($_SESSION['userconf']['previous_server']) && $_SESSION['userconf']['previous_server'] != $GLOBALS['server']) {
-            unset($_SESSION['userconf']['navi_limit_offset']);
+        if (isset($_SESSION['tmp_user_values']['previous_server']) && $_SESSION['tmp_user_values']['previous_server'] != $GLOBALS['server']) {
+            unset($_SESSION['tmp_user_values']['navi_limit_offset']);
         }
-        $_SESSION['userconf']['previous_server'] = $GLOBALS['server'];
+        $_SESSION['tmp_user_values']['previous_server'] = $GLOBALS['server'];
 
     } // end server connecting
 
@@ -931,6 +970,14 @@ if (! defined('PMA_MINIMUM_COMMON')) {
         unset($_SESSION['profiling']);
     }
 
+    // rajk - library file for blobstreaming
+    require_once './libraries/blobstreaming.lib.php';
+
+    // rajk - checks for blobstreaming plugins and databases that support
+    // blobstreaming (by having the necessary tables for blobstreaming)
+    if (checkBLOBStreamingPlugins()) {
+        checkBLOBStreamableDatabases();
+    }
 } // end if !defined('PMA_MINIMUM_COMMON')
 
 // remove sensitive values from session
@@ -938,6 +985,9 @@ $_SESSION['PMA_Config']->set('blowfish_secret', '');
 $_SESSION['PMA_Config']->set('Servers', '');
 $_SESSION['PMA_Config']->set('default_server', '');
 
+/* Tell tracker that it can actually work */
+PMA_Tracker::enable();
+
 if (!empty($__redirect) && in_array($__redirect, $goto_whitelist)) {
     /**
      * include subform target page
